import { DatePipe } from '@angular/common';
import { Component, EventEmitter, Input, OnInit, Output } from '@angular/core';
import { UntypedFormGroup } from '@angular/forms';
import { Structure } from '../../../../models/structure.model';
import { Module } from '../../../../structure-list/models/module.model';
import { RecapsType } from '../../enums/recapsType.enum';

@Component({
  selector: 'app-orientation-recap',
  templateUrl: './orientation-recap.component.html',
  styleUrls: ['./orientation-recap.component.scss'],
})
export class OrientationRecapComponent implements OnInit {
  @Input() form: UntypedFormGroup;
  @Input() recapType: RecapsType;
  @Output() checkValidation = new EventEmitter<any>();

  public needs: Module[];
  public structuresToPrint: Structure[];
  public orientator: { structureName: string; structureMail: string; structurePhone: string };
  public comment: string;
  public beneficiary: any;
  public recap: { day: string; hours: string; month: string; language: string };

  constructor(private datePipe: DatePipe) {}

  ngOnInit(): void {
    this.checkValidation.emit();
    this.needs = this.form.get('filters').value;
    this.beneficiary = {
      name: this.form.get('name').value,
      surname: this.form.get('surname').value,
    };
    switch (this.recapType) {
      case RecapsType.onlineMediation:
        this.handleOnlineOrientationRecap();
        break;
      case RecapsType.structure:
        this.handleStructureRecap();
        break;
      default:
        throw new Error(`Not implemented recap type ${this.recapType}`);
    }
  }

  public handleStructureRecap(): void {
    this.comment = this.form.get('comments').value;
    this.structuresToPrint = this.form.get('structureChoice').value;
    this.orientator = this.form.get('structureOrientator').value;
  }

  public isOrientator(): boolean {
    return this.orientator?.structureName ? true : false;
  }

  public handleOnlineOrientationRecap(): void {
    const monthNumber = parseInt(this.form.get('dateSlot').value.day.slice(-2));
    const monthName = this.datePipe.transform(`2000-${monthNumber}-01`, 'MMMM', 'fr');

    this.recap = {
      day: this.form.get('dateSlot').value.day.slice(0, -3),
      hours: this.form.get('dateSlot').value.hours.replace('-', ' et '),
      month: monthName,
      language: this.form.get('preferredLanguage').value,
    };
  }
}
